
# Slot: subject


A gene that has a role in modeling the disease. This may be a model organism ortholog of a known disease gene, or it may be a gene whose mutants recapitulate core features of the disease.

URI: [biolink:gene_as_a_model_of_disease_association_subject](https://w3id.org/biolink/vocab/gene_as_a_model_of_disease_association_subject)


## Domain and Range

[GeneAsAModelOfDiseaseAssociation](GeneAsAModelOfDiseaseAssociation.md) &#8594;  <sub>1..1</sub> [GeneOrGeneProduct](GeneOrGeneProduct.md)

## Parents

 *  is_a: [gene to disease association➞subject](gene_to_disease_association_subject.md)

## Children


## Used by

 * [GeneAsAModelOfDiseaseAssociation](GeneAsAModelOfDiseaseAssociation.md)
